==> apache-trafficcontrol-3.0.0.tar.gz: apache-trafficcontrol-3.0.0/traffic_portal/app/src/modules/private/parameters/profiles/index.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

module.exports = angular.module('trafficPortal.private.parameters.profiles', [])
	.config(function($stateProvider, $urlRouterProvider) {
		$stateProvider
			.state('trafficPortal.private.parameters.profiles', {
				url: '/{parameterId}/profiles',
				views: {
					parametersContent: {
						templateUrl: 'common/modules/table/parameterProfiles/table.parameterProfiles.tpl.html',
						controller: 'TableParameterProfilesController',
						resolve: {
							parameter: function($stateParams, parameterService) {
								return parameterService.getParameter($stateParams.parameterId);
							},
							parameterProfiles: function($stateParams, profileService) {
								return profileService.getParameterProfiles($stateParams.parameterId);
							}
						}
					}
				}
			})
		;
		$urlRouterProvider.otherwise('/');
	});

==> apache-trafficcontrol-7.0.1.tar.gz: apache-trafficcontrol-7.0.1/traffic_portal/app/src/modules/private/parameters/profiles/index.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

module.exports = angular.module('trafficPortal.private.parameters.profiles', [])
	.config(function($stateProvider, $urlRouterProvider) {
		$stateProvider
			.state('trafficPortal.private.parameters.profiles', {
				url: '/{parameterId}/profiles',
				views: {
					parametersContent: {
						templateUrl: 'common/modules/table/parameterProfiles/table.parameterProfiles.tpl.html',
						controller: 'TableParameterProfilesController',
						resolve: {
							parameter: function($stateParams, parameterService) {
								return parameterService.getParameter($stateParams.parameterId);
							},
							profiles: function($stateParams, profileService) {
								return profileService.getParameterProfiles($stateParams.parameterId);
							}
						}
					}
				}
			})
		;
		$urlRouterProvider.otherwise('/');
	});
